summaryrefslogtreecommitdiffstats
path: root/webkit/appcache/appcache_host.h
diff options
context:
space:
mode:
authorvsevik@chromium.org <vsevik@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-08 17:36:37 +0000
committervsevik@chromium.org <vsevik@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-08 17:36:37 +0000
commit7731bf2f4de4eb5a02b5dc95ac3edcea6e5b4abf (patch)
treef81e8c1a7c705565746dc18bfb9ef0e3d80dd38c /webkit/appcache/appcache_host.h
parent8fff20b5a494b253e3aa316e552b39aa31e179ae (diff)
downloadchromium_src-7731bf2f4de4eb5a02b5dc95ac3edcea6e5b4abf.zip
chromium_src-7731bf2f4de4eb5a02b5dc95ac3edcea6e5b4abf.tar.gz
chromium_src-7731bf2f4de4eb5a02b5dc95ac3edcea6e5b4abf.tar.bz2
Made application cache manifest URL always available for DevTools.
BUG=102680 TEST=None Review URL: http://codereview.chromium.org/8438043 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@109043 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/appcache/appcache_host.h')
-rw-r--r--webkit/appcache/appcache_host.h27
1 files changed, 22 insertions, 5 deletions
diff --git a/webkit/appcache/appcache_host.h b/webkit/appcache/appcache_host.h
index c94a1b3..25d46f5 100644
--- a/webkit/appcache/appcache_host.h
+++ b/webkit/appcache/appcache_host.h
@@ -96,11 +96,25 @@ class APPCACHE_EXPORT AppCacheHost : public AppCacheStorage::Delegate,
// Support for devtools inspecting appcache resources.
void GetResourceList(std::vector<AppCacheResourceInfo>* resource_infos);
- // Establishes an association between this host and a cache. 'cache' may be
- // NULL to break any existing association. Associations are established
- // either thru the cache selection algorithm implemented (in this class),
- // or by the update algorithm (see AppCacheUpdateJob).
- void AssociateCache(AppCache* cache);
+ // Breaks any existing association between this host and a cache.
+ // 'manifest_url' is sent to DevTools as the manifest url that could have
+ // been associated before or could be associated later with this host.
+ // Associations are broken either thru the cache selection algorithm
+ // implemented in this class, or by the update algorithm (see
+ // AppCacheUpdateJob).
+ void AssociateNoCache(const GURL& manifest_url);
+
+ // Establishes an association between this host and an incomplete cache.
+ // 'manifest_url' is manifest url of the cache group being updated.
+ // Associations with incomplete caches are established by the update algorithm
+ // (see AppCacheUpdateJob).
+ void AssociateIncompleteCache(AppCache* cache, const GURL& manifest_url);
+
+ // Establishes an association between this host and a complete cache.
+ // Associations with complete caches are established either thru the cache
+ // selection algorithm implemented (in this class), or by the update algorithm
+ // (see AppCacheUpdateJob).
+ void AssociateCompleteCache(AppCache* cache);
// Adds a reference to the newest complete cache in a group, unless it's the
// same as the cache that is currently associated with the host.
@@ -140,6 +154,9 @@ class APPCACHE_EXPORT AppCacheHost : public AppCacheStorage::Delegate,
void LoadSelectedCache(int64 cache_id);
void LoadOrCreateGroup(const GURL& manifest_url);
+ // See public Associate*Host() methods above.
+ void AssociateCacheHelper(AppCache* cache, const GURL& manifest_url);
+
// AppCacheStorage::Delegate impl
virtual void OnCacheLoaded(AppCache* cache, int64 cache_id);
virtual void OnGroupLoaded(AppCacheGroup* group,